/*
 *    _           _             _   _
 *   (_) __ _  __| | __ _ _ __ | |_(_)_   _____
 *   | |/ _` |/ _` |/ _` | '_ \| __| \ \ / / _ \
 *   | | (_| | (_| | (_| | |_) | |_| |\ V /  __/
 *  _/ |\__,_|\__,_|\__,_| .__/ \__|_| \_/ \___|
 * |__/                  |_|
 *
 * This file is part of the Maverick Synergy Hotfixes Java SSH API
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited.
 *
 * Copyright (C) 2002-2021 JADAPTIVE Limited - All Rights Reserved
 *
 * Use of this software may also be covered by third-party licenses depending on the choices you make about what features to use.
 *
 * Please visit the link below to see additional third-party licenses and copyrights
 *
 * https://www.jadaptive.com/app/manpage/en/article/1565029/What-third-party-dependencies-does-the-Maverick-Synergy-API-have
 */

package com.sshtools.common.policy;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

import com.sshtools.common.auth.RequiredAuthenticationStrategy;
import com.sshtools.common.permissions.Permissions;

public class AuthenticationPolicy extends Permissions {

	int maximumPublicKeyVerificationAttempts = 10;
	String bannerMessage = "";
	boolean publicKeyVerificationIsFailedAuth = false;
	RequiredAuthenticationStrategy requiredAuthenticationStrategy = RequiredAuthenticationStrategy.ONCE_PER_CONNECTION;
	List<String> required = new ArrayList<String>();
	protected int maxAuthentications = 10;
	
	/**
	 * Get the authentication banner to display to connecting clients.
	 * 
	 * @return String
	 */
	public String getBannerMessage() {
		return bannerMessage;
	}
	
	/**
	 * Set the banner message that is displayed to all connecing clients prior
	 * to authentication.
	 * 
	 * If this method is used then
	 * com.maverick.sshd.NoneAuthentication.getBannerForUser(String) should not
	 * be overridden.
	 * 
	 * @param authenticationBanner
	 */
	public void setBannerMessage(String authenticationBanner) {
		this.bannerMessage = authenticationBanner;
	}
	
	/**
	 * Get the number of public keys that each user can attempt to verify for
	 * public key authentication. If the user exceeds this limit the connection
	 * is terminated.
	 * 
	 * @return int
	 */
	public int getMaximumPublicKeyVerificationAttempts() {
		return maximumPublicKeyVerificationAttempts;
	}

	/**
	 * Set the number of public keys that a user can verify for public key
	 * authentication. If the user exceeds this limit the connection is
	 * terminated.
	 * 
	 * @param maximumPublicKeyVerificationAttempts
	 *            int
	 */
	public void setMaximumPublicKeyVerificationAttempts(
			int maximumPublicKeyVerificationAttempts) {
		this.maximumPublicKeyVerificationAttempts = maximumPublicKeyVerificationAttempts;
	}
	
	public void setPublicKeyVerificationIsFailedAuth(
			boolean publicKeyVerificationIsFailedAuth) {
		this.publicKeyVerificationIsFailedAuth = publicKeyVerificationIsFailedAuth;
	}

	public boolean isPublicKeyVerificationFailedAuth() {
		return publicKeyVerificationIsFailedAuth;
	}
	

	public void setRequiredAuthenticationStrategy(RequiredAuthenticationStrategy requiredAuthenticationStrategy) {
		this.requiredAuthenticationStrategy = requiredAuthenticationStrategy;
	}
	
	public RequiredAuthenticationStrategy getRequiredAuthenticationStrategy() {
		return requiredAuthenticationStrategy;
	}

	public void addRequiredMechanism(String auth) {
		required.add(auth);
	}
	
	public Collection<String> getRequiredMechanisms() {
		return Collections.unmodifiableCollection(required);
	}
	
	/**
	 * Get the maximum number of failed authentications allowed for each
	 * connection.
	 * 
	 * @return int
	 */
	public int getMaxAuthentications() {
		return maxAuthentications;
	}

	/**
	 * Set the maximum number of failed authentications allowed for each
	 * connection.
	 * 
	 * @param maxAuthentications
	 */
	public void setMaxAuthentications(int maxAuthentications) {
		this.maxAuthentications = maxAuthentications;
	}
}
