/*
 *    _           _             _   _
 *   (_) __ _  __| | __ _ _ __ | |_(_)_   _____
 *   | |/ _` |/ _` |/ _` | '_ \| __| \ \ / / _ \
 *   | | (_| | (_| | (_| | |_) | |_| |\ V /  __/
 *  _/ |\__,_|\__,_|\__,_| .__/ \__|_| \_/ \___|
 * |__/                  |_|
 *
 * This file is part of the Maverick Synergy Hotfixes Java SSH API
 *
 * Unauthorized copying of this file, via any medium is strictly prohibited.
 *
 * Copyright (C) 2002-2021 JADAPTIVE Limited - All Rights Reserved
 *
 * Use of this software may also be covered by third-party licenses depending on the choices you make about what features to use.
 *
 * Please visit the link below to see additional third-party licenses and copyrights
 *
 * https://www.jadaptive.com/app/manpage/en/article/1565029/What-third-party-dependencies-does-the-Maverick-Synergy-API-have
 */

package com.sshtools.client;

import java.io.File;

import com.sshtools.common.publickey.SshKeyUtils;

/**
 * Implements public key authentication, taking a java.io.File object as the source private key.
 */
public class PrivateKeyFileAuthenticator extends PublicKeyAuthenticator {

	File keyfile;
	String passphrase;
	
	public PrivateKeyFileAuthenticator(File keyfile, String passphrase) {
		this.keyfile = keyfile;
		this.passphrase = passphrase;
	}
	
	public PrivateKeyFileAuthenticator(File keyfile) {
		this.keyfile = keyfile;
	}
	
	public String getPassphrase() {
		return passphrase;
	}
	
	@Override
	public void authenticate(TransportProtocolClient transport, String username) {
		
		try {
			String passphrase = getPassphrase();
			addKeyPair(SshKeyUtils.getPrivateKey(keyfile, passphrase));
			if(SshKeyUtils.hasCertificate(keyfile)) {
				addKeyPair(SshKeyUtils.getCertificate(keyfile, passphrase));
			}
			super.authenticate(transport, username);
		} catch (Exception e) {
			throw new IllegalStateException(e.getMessage(), e);
		}
	}

}
